@@ -27,7 +27,7 @@ _4CHAN_THUMBS_URL = '0.t.4cdn.org'
 
 _BOARD = '%s/%i.json'
 _THREAD = '%s/res/%i.json'
-_VERSION = '0.2.2'
+_VERSION = '0.2.3'
 
 class Board(object):
     def __init__(self, boardName, https = False, apiUrl = _4CHAN_API, session = None):
@@ -115,7 +115,7 @@ class Board(object):
         return self._board_name
 
     def __repr__(self):
-        return '<Board /%s/>' % self.name
+        return '<Board /%s/>' % self.Name
 
 class Thread(object):
     def __init__(self, board, id):
@@ -136,7 +136,7 @@ class Thread(object):
             Is the thread closed?
             :return: bool
         """
-        return self.topic._data['closed'] == 1
+        return self.topic._data.get('closed', 0) == 1
 
     @property
     def Sticky(self):
@@ -144,7 +144,7 @@ class Thread(object):
             Is the thread sticky?
             :return: bool
         """
-        return self.topic._data['sticky'] == 1
+        return self.topic._data.get('sticky', 0) == 1
 
     @staticmethod
     def _fromRequest(board, res, id):
